#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="imaging_api.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

import six

from asposeimagingcloud.api_client import ApiClient
from asposeimagingcloud.configuration import Configuration
from asposeimagingcloud.rest import ApiException


class ImagingApi(object):
    """
    Aspose.Imaging Cloud API

    """

    def __init__(self, app_key=None, app_sid=None, base_url=None,
                 api_version=None, debug=False):
        """
        Initializes a new instance of the ImagingApi class.

        :param app_key: The app key.
        :param app_sid: The app sid.
        :param base_url: The base URL.
        :param api_version: API version.
        :param debug: If debug mode is enabled. False by default.
        :param on_premise:
            True for on-premise solution with metered license usage.
            False for Aspose Cloud-hosted solution usage, default.
        """
        configuration = Configuration(app_key=app_key,
                                      app_sid=app_sid,
                                      base_url=base_url,
                                      api_version=api_version,
                                      debug=debug)
        self.api_client = ApiClient(configuration)

    def add_search_image(self, request):
        """Add image and images features to search context. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request add_search_image_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', None)

    def add_search_image_async(self, request):
        """Add image and images features to search context. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request add_search_image_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', None)

    def append_tiff(self, request):
        """Appends existing TIFF image to another existing TIFF image (i.e. merges TIFF images).


        :param request append_tiff_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', None)

    def append_tiff_async(self, request):
        """Appends existing TIFF image to another existing TIFF image (i.e. merges TIFF images).


        :param request append_tiff_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', None)

    def compare_images(self, request):
        """Compare two images. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request compare_images_request object with parameters
        :return: SearchResultsSet
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'SearchResultsSet')

    def compare_images_async(self, request):
        """Compare two images. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request compare_images_request object with parameters
        :return: SearchResultsSet
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'SearchResultsSet')

    def convert_image(self, request):
        """Convert existing image to another format.


        :param request convert_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def convert_image_async(self, request):
        """Convert existing image to another format.


        :param request convert_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def convert_tiff_to_fax(self, request):
        """Update parameters of existing TIFF image accordingly to fax parameters.


        :param request convert_tiff_to_fax_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def convert_tiff_to_fax_async(self, request):
        """Update parameters of existing TIFF image accordingly to fax parameters.


        :param request convert_tiff_to_fax_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def copy_file(self, request):
        """Copy file


        :param request copy_file_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'PUT', None)

    def copy_file_async(self, request):
        """Copy file


        :param request copy_file_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'PUT', None)

    def copy_folder(self, request):
        """Copy folder


        :param request copy_folder_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'PUT', None)

    def copy_folder_async(self, request):
        """Copy folder


        :param request copy_folder_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'PUT', None)

    def create_converted_image(self, request):
        """Convert existing image to another format. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.             


        :param request create_converted_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_converted_image_async(self, request):
        """Convert existing image to another format. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.             


        :param request create_converted_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_cropped_image(self, request):
        """Crop an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_cropped_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_cropped_image_async(self, request):
        """Crop an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_cropped_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_deskewed_image(self, request):
        """Deskew an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_deskewed_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_deskewed_image_async(self, request):
        """Deskew an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_deskewed_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_fax_tiff(self, request):
        """Update parameters of TIFF image accordingly to fax parameters. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_fax_tiff_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_fax_tiff_async(self, request):
        """Update parameters of TIFF image accordingly to fax parameters. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_fax_tiff_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_folder(self, request):
        """Create the folder


        :param request create_folder_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'PUT', None)

    def create_folder_async(self, request):
        """Create the folder


        :param request create_folder_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'PUT', None)

    def create_grayscaled_image(self, request):
        """Grayscales an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_grayscaled_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_grayscaled_image_async(self, request):
        """Grayscales an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_grayscaled_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_image_features(self, request):
        """Extract images features and add them to search context. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_image_features_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', None)

    def create_image_features_async(self, request):
        """Extract images features and add them to search context. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_image_features_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', None)

    def create_image_frame(self, request):
        """Get separate frame from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_image_frame_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_image_frame_async(self, request):
        """Get separate frame from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_image_frame_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_image_frame_range(self, request):
        """Get frames range from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_image_frame_range_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_image_frame_range_async(self, request):
        """Get frames range from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_image_frame_range_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_image_search(self, request):
        """Create new search context.


        :param request create_image_search_request object with parameters
        :return: SearchContextStatus
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'SearchContextStatus')

    def create_image_search_async(self, request):
        """Create new search context.


        :param request create_image_search_request object with parameters
        :return: SearchContextStatus
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'SearchContextStatus')

    def create_image_tag(self, request):
        """Add tag and reference image to search context. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_image_tag_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', None)

    def create_image_tag_async(self, request):
        """Add tag and reference image to search context. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_image_tag_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', None)

    def create_modified_bmp(self, request):
        """Update parameters of BMP image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_bmp_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_modified_bmp_async(self, request):
        """Update parameters of BMP image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_bmp_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_modified_emf(self, request):
        """Process existing EMF imaging using given parameters. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_emf_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_modified_emf_async(self, request):
        """Process existing EMF imaging using given parameters. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_emf_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_modified_gif(self, request):
        """Update parameters of GIF image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_gif_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_modified_gif_async(self, request):
        """Update parameters of GIF image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_gif_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_modified_jpeg(self, request):
        """Update parameters of JPEG image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_jpeg_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_modified_jpeg_async(self, request):
        """Update parameters of JPEG image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_jpeg_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_modified_jpeg2000(self, request):
        """Update parameters of JPEG2000 image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_jpeg2000_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_modified_jpeg2000_async(self, request):
        """Update parameters of JPEG2000 image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_jpeg2000_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_modified_psd(self, request):
        """Update parameters of PSD image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_psd_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_modified_psd_async(self, request):
        """Update parameters of PSD image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_psd_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_modified_svg(self, request):
        """Update parameters of SVG image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_svg_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_modified_svg_async(self, request):
        """Update parameters of SVG image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_svg_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_modified_tiff(self, request):
        """Update parameters of TIFF image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_tiff_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_modified_tiff_async(self, request):
        """Update parameters of TIFF image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_tiff_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_modified_web_p(self, request):
        """Update parameters of WEBP image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_web_p_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_modified_web_p_async(self, request):
        """Update parameters of WEBP image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_web_p_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_modified_wmf(self, request):
        """Process existing WMF image using given parameters. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_wmf_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_modified_wmf_async(self, request):
        """Process existing WMF image using given parameters. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_modified_wmf_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_object_bounds(self, request):
        """Detects objects bounds. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_object_bounds_request object with parameters
        :return: DetectedObjectList
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'DetectedObjectList')

    def create_object_bounds_async(self, request):
        """Detects objects bounds. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_object_bounds_request object with parameters
        :return: DetectedObjectList
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'DetectedObjectList')

    def create_resized_image(self, request):
        """Resize an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_resized_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_resized_image_async(self, request):
        """Resize an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_resized_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_rotate_flipped_image(self, request):
        """Rotate and/or flip an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_rotate_flipped_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_rotate_flipped_image_async(self, request):
        """Rotate and/or flip an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_rotate_flipped_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_updated_image(self, request):
        """Perform scaling, cropping and flipping of an image in a single request. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_updated_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_updated_image_async(self, request):
        """Perform scaling, cropping and flipping of an image in a single request. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request create_updated_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_visual_object_bounds(self, request):
        """Detects objects bounds and draw them on the original image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream


        :param request create_visual_object_bounds_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'file')

    def create_visual_object_bounds_async(self, request):
        """Detects objects bounds and draw them on the original image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream


        :param request create_visual_object_bounds_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'file')

    def create_web_site_image_features(self, request):
        """Extract images features from web page and add them to search context


        :param request create_web_site_image_features_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', None)

    def create_web_site_image_features_async(self, request):
        """Extract images features from web page and add them to search context


        :param request create_web_site_image_features_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', None)

    def crop_image(self, request):
        """Crop an existing image.


        :param request crop_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def crop_image_async(self, request):
        """Crop an existing image.


        :param request crop_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def delete_file(self, request):
        """Delete file


        :param request delete_file_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'DELETE', None)

    def delete_file_async(self, request):
        """Delete file


        :param request delete_file_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'DELETE', None)

    def delete_folder(self, request):
        """Delete folder


        :param request delete_folder_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'DELETE', None)

    def delete_folder_async(self, request):
        """Delete folder


        :param request delete_folder_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'DELETE', None)

    def delete_image_features(self, request):
        """Deletes image features from search context.


        :param request delete_image_features_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'DELETE', None)

    def delete_image_features_async(self, request):
        """Deletes image features from search context.


        :param request delete_image_features_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'DELETE', None)

    def delete_image_search(self, request):
        """Deletes the search context.


        :param request delete_image_search_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'DELETE', None)

    def delete_image_search_async(self, request):
        """Deletes the search context.


        :param request delete_image_search_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'DELETE', None)

    def delete_search_image(self, request):
        """Delete image and images features from search context


        :param request delete_search_image_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'DELETE', None)

    def delete_search_image_async(self, request):
        """Delete image and images features from search context


        :param request delete_search_image_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'DELETE', None)

    def deskew_image(self, request):
        """Deskew an existing image.


        :param request deskew_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def deskew_image_async(self, request):
        """Deskew an existing image.


        :param request deskew_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def download_file(self, request):
        """Download file


        :param request download_file_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def download_file_async(self, request):
        """Download file


        :param request download_file_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def extract_image_features(self, request):
        """Extract features from image without adding to search context. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request extract_image_features_request object with parameters
        :return: ImageFeatures
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'ImageFeatures')

    def extract_image_features_async(self, request):
        """Extract features from image without adding to search context. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request extract_image_features_request object with parameters
        :return: ImageFeatures
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'ImageFeatures')

    def extract_image_frame_properties(self, request):
        """Get separate frame properties of existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request extract_image_frame_properties_request object with parameters
        :return: ImagingResponse
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'ImagingResponse')

    def extract_image_frame_properties_async(self, request):
        """Get separate frame properties of existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request extract_image_frame_properties_request object with parameters
        :return: ImagingResponse
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'ImagingResponse')

    def extract_image_properties(self, request):
        """Get properties of an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request extract_image_properties_request object with parameters
        :return: ImagingResponse
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'ImagingResponse')

    def extract_image_properties_async(self, request):
        """Get properties of an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request extract_image_properties_request object with parameters
        :return: ImagingResponse
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'ImagingResponse')

    def filter_effect_image(self, request):
        """Apply filtering effects to an existing image.


        :param request filter_effect_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'PUT', 'file')

    def filter_effect_image_async(self, request):
        """Apply filtering effects to an existing image.


        :param request filter_effect_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'PUT', 'file')

    def find_image_duplicates(self, request):
        """Find images duplicates.


        :param request find_image_duplicates_request object with parameters
        :return: ImageDuplicatesSet
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'ImageDuplicatesSet')

    def find_image_duplicates_async(self, request):
        """Find images duplicates.


        :param request find_image_duplicates_request object with parameters
        :return: ImageDuplicatesSet
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'ImageDuplicatesSet')

    def find_images_by_tags(self, request):
        """Find images by tags. Tags JSON string is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request find_images_by_tags_request object with parameters
        :return: SearchResultsSet
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'POST', 'SearchResultsSet')

    def find_images_by_tags_async(self, request):
        """Find images by tags. Tags JSON string is passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request find_images_by_tags_request object with parameters
        :return: SearchResultsSet
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'POST', 'SearchResultsSet')

    def find_similar_images(self, request):
        """Find similar images. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request find_similar_images_request object with parameters
        :return: SearchResultsSet
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'SearchResultsSet')

    def find_similar_images_async(self, request):
        """Find similar images. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request find_similar_images_request object with parameters
        :return: SearchResultsSet
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'SearchResultsSet')

    def get_available_labels(self, request):
        """Gets available labels for selected object detection method.


        :param request get_available_labels_request object with parameters
        :return: AvailableLabelsList
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'AvailableLabelsList')

    def get_available_labels_async(self, request):
        """Gets available labels for selected object detection method.


        :param request get_available_labels_request object with parameters
        :return: AvailableLabelsList
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'AvailableLabelsList')

    def get_disc_usage(self, request):
        """Get disc usage


        :param request get_disc_usage_request object with parameters
        :return: DiscUsage
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'DiscUsage')

    def get_disc_usage_async(self, request):
        """Get disc usage


        :param request get_disc_usage_request object with parameters
        :return: DiscUsage
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'DiscUsage')

    def get_file_versions(self, request):
        """Get file versions


        :param request get_file_versions_request object with parameters
        :return: FileVersions
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'FileVersions')

    def get_file_versions_async(self, request):
        """Get file versions


        :param request get_file_versions_request object with parameters
        :return: FileVersions
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'FileVersions')

    def get_files_list(self, request):
        """Get all files and folders within a folder


        :param request get_files_list_request object with parameters
        :return: FilesList
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'FilesList')

    def get_files_list_async(self, request):
        """Get all files and folders within a folder


        :param request get_files_list_request object with parameters
        :return: FilesList
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'FilesList')

    def get_image_features(self, request):
        """Gets image features from search context.


        :param request get_image_features_request object with parameters
        :return: ImageFeatures
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'ImageFeatures')

    def get_image_features_async(self, request):
        """Gets image features from search context.


        :param request get_image_features_request object with parameters
        :return: ImageFeatures
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'ImageFeatures')

    def get_image_frame(self, request):
        """Get separate frame from existing image.


        :param request get_image_frame_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def get_image_frame_async(self, request):
        """Get separate frame from existing image.


        :param request get_image_frame_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def get_image_frame_properties(self, request):
        """Get separate frame properties of existing image.


        :param request get_image_frame_properties_request object with parameters
        :return: ImagingResponse
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'ImagingResponse')

    def get_image_frame_properties_async(self, request):
        """Get separate frame properties of existing image.


        :param request get_image_frame_properties_request object with parameters
        :return: ImagingResponse
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'ImagingResponse')

    def get_image_frame_range(self, request):
        """Get frames range from existing image.


        :param request get_image_frame_range_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def get_image_frame_range_async(self, request):
        """Get frames range from existing image.


        :param request get_image_frame_range_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def get_image_properties(self, request):
        """Get properties of an image.


        :param request get_image_properties_request object with parameters
        :return: ImagingResponse
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'ImagingResponse')

    def get_image_properties_async(self, request):
        """Get properties of an image.


        :param request get_image_properties_request object with parameters
        :return: ImagingResponse
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'ImagingResponse')

    def get_image_search_status(self, request):
        """Gets the search context status.


        :param request get_image_search_status_request object with parameters
        :return: SearchContextStatus
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'SearchContextStatus')

    def get_image_search_status_async(self, request):
        """Gets the search context status.


        :param request get_image_search_status_request object with parameters
        :return: SearchContextStatus
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'SearchContextStatus')

    def get_object_bounds(self, request):
        """Detects objects&#39; bounds


        :param request get_object_bounds_request object with parameters
        :return: DetectedObjectList
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'DetectedObjectList')

    def get_object_bounds_async(self, request):
        """Detects objects&#39; bounds


        :param request get_object_bounds_request object with parameters
        :return: DetectedObjectList
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'DetectedObjectList')

    def get_search_image(self, request):
        """Get image from search context


        :param request get_search_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def get_search_image_async(self, request):
        """Get image from search context


        :param request get_search_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def get_visual_object_bounds(self, request):
        """Detects objects bounds and draw them on the original image


        :param request get_visual_object_bounds_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def get_visual_object_bounds_async(self, request):
        """Detects objects bounds and draw them on the original image


        :param request get_visual_object_bounds_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def grayscale_image(self, request):
        """Grayscale an existing image.


        :param request grayscale_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def grayscale_image_async(self, request):
        """Grayscale an existing image.


        :param request grayscale_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def modify_bmp(self, request):
        """Update parameters of existing BMP image.


        :param request modify_bmp_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def modify_bmp_async(self, request):
        """Update parameters of existing BMP image.


        :param request modify_bmp_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def modify_emf(self, request):
        """Process existing EMF imaging using given parameters.


        :param request modify_emf_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def modify_emf_async(self, request):
        """Process existing EMF imaging using given parameters.


        :param request modify_emf_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def modify_gif(self, request):
        """Update parameters of existing GIF image.


        :param request modify_gif_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def modify_gif_async(self, request):
        """Update parameters of existing GIF image.


        :param request modify_gif_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def modify_jpeg(self, request):
        """Update parameters of existing JPEG image.


        :param request modify_jpeg_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def modify_jpeg_async(self, request):
        """Update parameters of existing JPEG image.


        :param request modify_jpeg_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def modify_jpeg2000(self, request):
        """Update parameters of existing JPEG2000 image.


        :param request modify_jpeg2000_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def modify_jpeg2000_async(self, request):
        """Update parameters of existing JPEG2000 image.


        :param request modify_jpeg2000_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def modify_psd(self, request):
        """Update parameters of existing PSD image.


        :param request modify_psd_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def modify_psd_async(self, request):
        """Update parameters of existing PSD image.


        :param request modify_psd_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def modify_svg(self, request):
        """Update parameters of existing SVG image.


        :param request modify_svg_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def modify_svg_async(self, request):
        """Update parameters of existing SVG image.


        :param request modify_svg_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def modify_tiff(self, request):
        """Update parameters of existing TIFF image.


        :param request modify_tiff_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def modify_tiff_async(self, request):
        """Update parameters of existing TIFF image.


        :param request modify_tiff_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def modify_web_p(self, request):
        """Update parameters of existing WEBP image.


        :param request modify_web_p_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def modify_web_p_async(self, request):
        """Update parameters of existing WEBP image.


        :param request modify_web_p_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def modify_wmf(self, request):
        """Process existing WMF image using given parameters.


        :param request modify_wmf_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def modify_wmf_async(self, request):
        """Process existing WMF image using given parameters.


        :param request modify_wmf_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def move_file(self, request):
        """Move file


        :param request move_file_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'PUT', None)

    def move_file_async(self, request):
        """Move file


        :param request move_file_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'PUT', None)

    def move_folder(self, request):
        """Move folder


        :param request move_folder_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'PUT', None)

    def move_folder_async(self, request):
        """Move folder


        :param request move_folder_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'PUT', None)

    def object_exists(self, request):
        """Check if file or folder exists


        :param request object_exists_request object with parameters
        :return: ObjectExist
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'ObjectExist')

    def object_exists_async(self, request):
        """Check if file or folder exists


        :param request object_exists_request object with parameters
        :return: ObjectExist
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'ObjectExist')

    def resize_image(self, request):
        """Resize an existing image.


        :param request resize_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def resize_image_async(self, request):
        """Resize an existing image.


        :param request resize_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def rotate_flip_image(self, request):
        """Rotate and/or flip an existing image.


        :param request rotate_flip_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def rotate_flip_image_async(self, request):
        """Rotate and/or flip an existing image.


        :param request rotate_flip_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def storage_exists(self, request):
        """Check if storage exists


        :param request storage_exists_request object with parameters
        :return: StorageExist
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'StorageExist')

    def storage_exists_async(self, request):
        """Check if storage exists


        :param request storage_exists_request object with parameters
        :return: StorageExist
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'StorageExist')

    def update_image(self, request):
        """Perform scaling, cropping and flipping of an existing image in a single request.


        :param request update_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'GET', 'file')

    def update_image_async(self, request):
        """Perform scaling, cropping and flipping of an existing image in a single request.


        :param request update_image_request object with parameters
        :return: file
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'GET', 'file')

    def update_image_features(self, request):
        """Update images features in search context. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request update_image_features_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'PUT', None)

    def update_image_features_async(self, request):
        """Update images features in search context. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request update_image_features_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'PUT', None)

    def update_search_image(self, request):
        """Update image and images features in search context. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request update_search_image_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'PUT', None)

    def update_search_image_async(self, request):
        """Update image and images features in search context. Image data may be passed as zero-indexed multipart/form-data content or as raw body stream.


        :param request update_search_image_request object with parameters
        :return: None
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'PUT', None)

    def upload_file(self, request):
        """Upload file


        :param request upload_file_request object with parameters
        :return: FilesUploadResult
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request(http_request, 'PUT', 'FilesUploadResult')

    def upload_file_async(self, request):
        """Upload file


        :param request upload_file_request object with parameters
        :return: FilesUploadResult
        """
        http_request = request.to_http_info(self.api_client.configuration)
        return self.__make_request_async(http_request, 'PUT', 'FilesUploadResult')

    def __make_request(self, http_request, method, return_type):
        def call_api():
            return self.api_client.call_api(
                resource_path=http_request.resource_path,
                method=method,
                path_params=http_request.path_params,
                query_params=http_request.query_params,
                header_params=http_request.header_params,
                body=http_request.body_params,
                post_params=http_request.form_params,
                files=http_request.files,
                response_type=return_type,
                auth_settings=http_request.auth_settings,
                _return_http_data_only=http_request.return_http_data_only,
                _preload_content=http_request.preload_content,
                _request_timeout=http_request.request_timeout,
                collection_formats=http_request.collection_formats)

        try:
            return call_api()
        except ApiException as ex:
            if ex.code == 401:
                self.__request_token()
                return call_api()
            raise

    def __make_request_async(self, http_request, method, return_type):
        def call_api_async():
            self.api_client.call_api_async(
                resource_path=http_request.resource_path,
                method=method,
                path_params=http_request.path_params,
                query_params=http_request.query_params,
                header_params=http_request.header_params,
                body=http_request.body_params,
                post_params=http_request.form_params,
                files=http_request.files,
                response_type=return_type,
                auth_settings=http_request.auth_settings,
                _return_http_data_only=http_request.return_http_data_only,
                _preload_content=http_request.preload_content,
                _request_timeout=http_request.request_timeout,
                collection_formats=http_request.collection_formats)

        try:
            return call_api_async()
        except ApiException as ex:
            if ex.code == 401:
                self.__request_token()
                return call_api_async()
            raise

    def __request_token(self):
        config = self.api_client.configuration
        request_url = "/connect/token"
        form_params = [('grant_type', 'client_credentials'), ('client_id', config.api_key['app_sid']),
                       ('client_secret', config.api_key['api_key'])]

        header_params = {'Accept': 'application/json', 'Content-Type': 'application/x-www-form-urlencoded'}

        api_version = self.api_client.configuration.api_version
        self.api_client.configuration.api_version = ''

        data = self.api_client.call_api(request_url, 'POST',
                                        {},
                                        [],
                                        header_params,
                                        post_params=form_params,
                                        response_type='object',
                                        files={}, _return_http_data_only=True)
        access_token = data['access_token'] if six.PY3 else data['access_token'].encode('utf8')
        self.api_client.configuration.access_token = access_token

        self.api_client.configuration.api_version = api_version




#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="imaging_response.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six

from asposeimagingcloud.models.bmp_properties import BmpProperties
from asposeimagingcloud.models.dicom_properties import DicomProperties
from asposeimagingcloud.models.djvu_properties import DjvuProperties
from asposeimagingcloud.models.dng_properties import DngProperties
from asposeimagingcloud.models.eps_properties import EpsProperties
from asposeimagingcloud.models.gif_properties import GifProperties
from asposeimagingcloud.models.jpeg2000_properties import Jpeg2000Properties
from asposeimagingcloud.models.jpeg_properties import JpegProperties
from asposeimagingcloud.models.odg_properties import OdgProperties
from asposeimagingcloud.models.png_properties import PngProperties
from asposeimagingcloud.models.psd_properties import PsdProperties
from asposeimagingcloud.models.svg_properties import SvgProperties
from asposeimagingcloud.models.tiff_properties import TiffProperties
from asposeimagingcloud.models.web_p_properties import WebPProperties


class ImagingResponse(object):
    """Represents information about image.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'height': 'int',
        'width': 'int',
        'bits_per_pixel': 'int',
        'bmp_properties': 'BmpProperties',
        'gif_properties': 'GifProperties',
        'jpeg_properties': 'JpegProperties',
        'png_properties': 'PngProperties',
        'tiff_properties': 'TiffProperties',
        'psd_properties': 'PsdProperties',
        'djvu_properties': 'DjvuProperties',
        'web_p_properties': 'WebPProperties',
        'jpeg2000_properties': 'Jpeg2000Properties',
        'dicom_properties': 'DicomProperties',
        'dng_properties': 'DngProperties',
        'odg_properties': 'OdgProperties',
        'svg_properties': 'SvgProperties',
        'eps_properties': 'EpsProperties',
        'horizontal_resolution': 'float',
        'vertical_resolution': 'float',
        'is_cached': 'bool'
    }

    attribute_map = {
        'height': 'Height',
        'width': 'Width',
        'bits_per_pixel': 'BitsPerPixel',
        'bmp_properties': 'BmpProperties',
        'gif_properties': 'GifProperties',
        'jpeg_properties': 'JpegProperties',
        'png_properties': 'PngProperties',
        'tiff_properties': 'TiffProperties',
        'psd_properties': 'PsdProperties',
        'djvu_properties': 'DjvuProperties',
        'web_p_properties': 'WebPProperties',
        'jpeg2000_properties': 'Jpeg2000Properties',
        'dicom_properties': 'DicomProperties',
        'dng_properties': 'DngProperties',
        'odg_properties': 'OdgProperties',
        'svg_properties': 'SvgProperties',
        'eps_properties': 'EpsProperties',
        'horizontal_resolution': 'HorizontalResolution',
        'vertical_resolution': 'VerticalResolution',
        'is_cached': 'IsCached'
    }

    def __init__(self, height=None, width=None, bits_per_pixel=None, bmp_properties=None, gif_properties=None, jpeg_properties=None, png_properties=None, tiff_properties=None, psd_properties=None, djvu_properties=None, web_p_properties=None, jpeg2000_properties=None, dicom_properties=None, dng_properties=None, odg_properties=None, svg_properties=None, eps_properties=None, horizontal_resolution=None, vertical_resolution=None, is_cached=None):
        """ImagingResponse - a model defined in Swagger"""
        super(ImagingResponse, self).__init__()

        self._height = None
        self._width = None
        self._bits_per_pixel = None
        self._bmp_properties = None
        self._gif_properties = None
        self._jpeg_properties = None
        self._png_properties = None
        self._tiff_properties = None
        self._psd_properties = None
        self._djvu_properties = None
        self._web_p_properties = None
        self._jpeg2000_properties = None
        self._dicom_properties = None
        self._dng_properties = None
        self._odg_properties = None
        self._svg_properties = None
        self._eps_properties = None
        self._horizontal_resolution = None
        self._vertical_resolution = None
        self._is_cached = None

        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        if bits_per_pixel is not None:
            self.bits_per_pixel = bits_per_pixel
        if bmp_properties is not None:
            self.bmp_properties = bmp_properties
        if gif_properties is not None:
            self.gif_properties = gif_properties
        if jpeg_properties is not None:
            self.jpeg_properties = jpeg_properties
        if png_properties is not None:
            self.png_properties = png_properties
        if tiff_properties is not None:
            self.tiff_properties = tiff_properties
        if psd_properties is not None:
            self.psd_properties = psd_properties
        if djvu_properties is not None:
            self.djvu_properties = djvu_properties
        if web_p_properties is not None:
            self.web_p_properties = web_p_properties
        if jpeg2000_properties is not None:
            self.jpeg2000_properties = jpeg2000_properties
        if dicom_properties is not None:
            self.dicom_properties = dicom_properties
        if dng_properties is not None:
            self.dng_properties = dng_properties
        if odg_properties is not None:
            self.odg_properties = odg_properties
        if svg_properties is not None:
            self.svg_properties = svg_properties
        if eps_properties is not None:
            self.eps_properties = eps_properties
        if horizontal_resolution is not None:
            self.horizontal_resolution = horizontal_resolution
        if vertical_resolution is not None:
            self.vertical_resolution = vertical_resolution
        if is_cached is not None:
            self.is_cached = is_cached

    @property
    def height(self):
        """Gets the height of this ImagingResponse.

        Gets or sets the height of image.

        :return: The height of this ImagingResponse.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this ImagingResponse.

        Gets or sets the height of image.

        :param height: The height of this ImagingResponse.
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")
        self._height = height

    @property
    def width(self):
        """Gets the width of this ImagingResponse.

        Gets or sets the width of image.

        :return: The width of this ImagingResponse.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this ImagingResponse.

        Gets or sets the width of image.

        :param width: The width of this ImagingResponse.
        :type: int
        """
        if width is None:
            raise ValueError("Invalid value for `width`, must not be `None`")
        self._width = width

    @property
    def bits_per_pixel(self):
        """Gets the bits_per_pixel of this ImagingResponse.

        Gets or sets the bits per pixel for image.

        :return: The bits_per_pixel of this ImagingResponse.
        :rtype: int
        """
        return self._bits_per_pixel

    @bits_per_pixel.setter
    def bits_per_pixel(self, bits_per_pixel):
        """Sets the bits_per_pixel of this ImagingResponse.

        Gets or sets the bits per pixel for image.

        :param bits_per_pixel: The bits_per_pixel of this ImagingResponse.
        :type: int
        """
        if bits_per_pixel is None:
            raise ValueError("Invalid value for `bits_per_pixel`, must not be `None`")
        self._bits_per_pixel = bits_per_pixel

    @property
    def bmp_properties(self):
        """Gets the bmp_properties of this ImagingResponse.

        Gets or sets the BMP properties.

        :return: The bmp_properties of this ImagingResponse.
        :rtype: BmpProperties
        """
        return self._bmp_properties

    @bmp_properties.setter
    def bmp_properties(self, bmp_properties):
        """Sets the bmp_properties of this ImagingResponse.

        Gets or sets the BMP properties.

        :param bmp_properties: The bmp_properties of this ImagingResponse.
        :type: BmpProperties
        """
        self._bmp_properties = bmp_properties

    @property
    def gif_properties(self):
        """Gets the gif_properties of this ImagingResponse.

        Gets or sets the GIF properties.

        :return: The gif_properties of this ImagingResponse.
        :rtype: GifProperties
        """
        return self._gif_properties

    @gif_properties.setter
    def gif_properties(self, gif_properties):
        """Sets the gif_properties of this ImagingResponse.

        Gets or sets the GIF properties.

        :param gif_properties: The gif_properties of this ImagingResponse.
        :type: GifProperties
        """
        self._gif_properties = gif_properties

    @property
    def jpeg_properties(self):
        """Gets the jpeg_properties of this ImagingResponse.

        Gets or sets the JPEG properties.

        :return: The jpeg_properties of this ImagingResponse.
        :rtype: JpegProperties
        """
        return self._jpeg_properties

    @jpeg_properties.setter
    def jpeg_properties(self, jpeg_properties):
        """Sets the jpeg_properties of this ImagingResponse.

        Gets or sets the JPEG properties.

        :param jpeg_properties: The jpeg_properties of this ImagingResponse.
        :type: JpegProperties
        """
        self._jpeg_properties = jpeg_properties

    @property
    def png_properties(self):
        """Gets the png_properties of this ImagingResponse.

        Gets or sets the PNG properties.

        :return: The png_properties of this ImagingResponse.
        :rtype: PngProperties
        """
        return self._png_properties

    @png_properties.setter
    def png_properties(self, png_properties):
        """Sets the png_properties of this ImagingResponse.

        Gets or sets the PNG properties.

        :param png_properties: The png_properties of this ImagingResponse.
        :type: PngProperties
        """
        self._png_properties = png_properties

    @property
    def tiff_properties(self):
        """Gets the tiff_properties of this ImagingResponse.

        Gets or sets the TIFF properties.

        :return: The tiff_properties of this ImagingResponse.
        :rtype: TiffProperties
        """
        return self._tiff_properties

    @tiff_properties.setter
    def tiff_properties(self, tiff_properties):
        """Sets the tiff_properties of this ImagingResponse.

        Gets or sets the TIFF properties.

        :param tiff_properties: The tiff_properties of this ImagingResponse.
        :type: TiffProperties
        """
        self._tiff_properties = tiff_properties

    @property
    def psd_properties(self):
        """Gets the psd_properties of this ImagingResponse.

        Gets or sets the PSD properties.

        :return: The psd_properties of this ImagingResponse.
        :rtype: PsdProperties
        """
        return self._psd_properties

    @psd_properties.setter
    def psd_properties(self, psd_properties):
        """Sets the psd_properties of this ImagingResponse.

        Gets or sets the PSD properties.

        :param psd_properties: The psd_properties of this ImagingResponse.
        :type: PsdProperties
        """
        self._psd_properties = psd_properties

    @property
    def djvu_properties(self):
        """Gets the djvu_properties of this ImagingResponse.

        Gets or sets the DJVU properties.

        :return: The djvu_properties of this ImagingResponse.
        :rtype: DjvuProperties
        """
        return self._djvu_properties

    @djvu_properties.setter
    def djvu_properties(self, djvu_properties):
        """Sets the djvu_properties of this ImagingResponse.

        Gets or sets the DJVU properties.

        :param djvu_properties: The djvu_properties of this ImagingResponse.
        :type: DjvuProperties
        """
        self._djvu_properties = djvu_properties

    @property
    def web_p_properties(self):
        """Gets the web_p_properties of this ImagingResponse.

        Gets or sets the WEBP properties.

        :return: The web_p_properties of this ImagingResponse.
        :rtype: WebPProperties
        """
        return self._web_p_properties

    @web_p_properties.setter
    def web_p_properties(self, web_p_properties):
        """Sets the web_p_properties of this ImagingResponse.

        Gets or sets the WEBP properties.

        :param web_p_properties: The web_p_properties of this ImagingResponse.
        :type: WebPProperties
        """
        self._web_p_properties = web_p_properties

    @property
    def jpeg2000_properties(self):
        """Gets the jpeg2000_properties of this ImagingResponse.

        Gets or sets the JPEG2000 properties.

        :return: The jpeg2000_properties of this ImagingResponse.
        :rtype: Jpeg2000Properties
        """
        return self._jpeg2000_properties

    @jpeg2000_properties.setter
    def jpeg2000_properties(self, jpeg2000_properties):
        """Sets the jpeg2000_properties of this ImagingResponse.

        Gets or sets the JPEG2000 properties.

        :param jpeg2000_properties: The jpeg2000_properties of this ImagingResponse.
        :type: Jpeg2000Properties
        """
        self._jpeg2000_properties = jpeg2000_properties

    @property
    def dicom_properties(self):
        """Gets the dicom_properties of this ImagingResponse.

        Gets or sets the DICOM properties.

        :return: The dicom_properties of this ImagingResponse.
        :rtype: DicomProperties
        """
        return self._dicom_properties

    @dicom_properties.setter
    def dicom_properties(self, dicom_properties):
        """Sets the dicom_properties of this ImagingResponse.

        Gets or sets the DICOM properties.

        :param dicom_properties: The dicom_properties of this ImagingResponse.
        :type: DicomProperties
        """
        self._dicom_properties = dicom_properties

    @property
    def dng_properties(self):
        """Gets the dng_properties of this ImagingResponse.

        Gets or sets the DNG properties.

        :return: The dng_properties of this ImagingResponse.
        :rtype: DngProperties
        """
        return self._dng_properties

    @dng_properties.setter
    def dng_properties(self, dng_properties):
        """Sets the dng_properties of this ImagingResponse.

        Gets or sets the DNG properties.

        :param dng_properties: The dng_properties of this ImagingResponse.
        :type: DngProperties
        """
        self._dng_properties = dng_properties

    @property
    def odg_properties(self):
        """Gets the odg_properties of this ImagingResponse.

        Gets or sets the the ODG properties.

        :return: The odg_properties of this ImagingResponse.
        :rtype: OdgProperties
        """
        return self._odg_properties

    @odg_properties.setter
    def odg_properties(self, odg_properties):
        """Sets the odg_properties of this ImagingResponse.

        Gets or sets the the ODG properties.

        :param odg_properties: The odg_properties of this ImagingResponse.
        :type: OdgProperties
        """
        self._odg_properties = odg_properties

    @property
    def svg_properties(self):
        """Gets the svg_properties of this ImagingResponse.

        Gets or sets the SVG properties.

        :return: The svg_properties of this ImagingResponse.
        :rtype: SvgProperties
        """
        return self._svg_properties

    @svg_properties.setter
    def svg_properties(self, svg_properties):
        """Sets the svg_properties of this ImagingResponse.

        Gets or sets the SVG properties.

        :param svg_properties: The svg_properties of this ImagingResponse.
        :type: SvgProperties
        """
        self._svg_properties = svg_properties

    @property
    def eps_properties(self):
        """Gets the eps_properties of this ImagingResponse.

        Gets or sets the EPS properties.

        :return: The eps_properties of this ImagingResponse.
        :rtype: EpsProperties
        """
        return self._eps_properties

    @eps_properties.setter
    def eps_properties(self, eps_properties):
        """Sets the eps_properties of this ImagingResponse.

        Gets or sets the EPS properties.

        :param eps_properties: The eps_properties of this ImagingResponse.
        :type: EpsProperties
        """
        self._eps_properties = eps_properties

    @property
    def horizontal_resolution(self):
        """Gets the horizontal_resolution of this ImagingResponse.

        Gets or sets the horizontal resolution of an image.

        :return: The horizontal_resolution of this ImagingResponse.
        :rtype: float
        """
        return self._horizontal_resolution

    @horizontal_resolution.setter
    def horizontal_resolution(self, horizontal_resolution):
        """Sets the horizontal_resolution of this ImagingResponse.

        Gets or sets the horizontal resolution of an image.

        :param horizontal_resolution: The horizontal_resolution of this ImagingResponse.
        :type: float
        """
        if horizontal_resolution is None:
            raise ValueError("Invalid value for `horizontal_resolution`, must not be `None`")
        self._horizontal_resolution = horizontal_resolution

    @property
    def vertical_resolution(self):
        """Gets the vertical_resolution of this ImagingResponse.

        Gets or sets the vertical resolution of an image.

        :return: The vertical_resolution of this ImagingResponse.
        :rtype: float
        """
        return self._vertical_resolution

    @vertical_resolution.setter
    def vertical_resolution(self, vertical_resolution):
        """Sets the vertical_resolution of this ImagingResponse.

        Gets or sets the vertical resolution of an image.

        :param vertical_resolution: The vertical_resolution of this ImagingResponse.
        :type: float
        """
        if vertical_resolution is None:
            raise ValueError("Invalid value for `vertical_resolution`, must not be `None`")
        self._vertical_resolution = vertical_resolution

    @property
    def is_cached(self):
        """Gets the is_cached of this ImagingResponse.

        Gets or sets a value indicating whether image is cached.

        :return: The is_cached of this ImagingResponse.
        :rtype: bool
        """
        return self._is_cached

    @is_cached.setter
    def is_cached(self, is_cached):
        """Sets the is_cached of this ImagingResponse.

        Gets or sets a value indicating whether image is cached.

        :param is_cached: The is_cached of this ImagingResponse.
        :type: bool
        """
        if is_cached is None:
            raise ValueError("Invalid value for `is_cached`, must not be `None`")
        self._is_cached = is_cached

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImagingResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
